@@ -14,28 +14,31 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
-*/
+ */
 
 #include "controlflownode.h"
 
 using namespace KDevelop;
 
 ControlFlowNode::ControlFlowNode()
-  : m_conditionRange(RangeInRevision::invalid())
+    : m_conditionRange(RangeInRevision::invalid())
 {}
 
 ControlFlowNode::Type ControlFlowNode::type() const
 {
-  Q_ASSERT(!m_alternative || m_next); //If we have alternative, we have next.
+    Q_ASSERT(!m_alternative || m_next); //If we have alternative, we have next.
 
-  if(m_next && m_alternative) return Conditional;
-  else if(m_next) return Sequential;
-  else return Exit;
+    if (m_next && m_alternative)
+        return Conditional;
+    else if (m_next)
+        return Sequential;
+    else
+        return Exit;
 }
 
 void ControlFlowNode::setConditionRange(const RangeInRevision& range)
 {
-    Q_ASSERT(!range.isValid() || range.end>=range.start);
+    Q_ASSERT(!range.isValid() || range.end >= range.start);
     m_conditionRange = range;
 }
 
@@ -56,7 +59,7 @@ void ControlFlowNode::setNext(ControlFlowNode* next)
 
 void ControlFlowNode::setAlternative(ControlFlowNode* alt)
 {
-    m_alternative=alt;
+    m_alternative = alt;
 }
 
 ControlFlowNode* ControlFlowNode::next() const
