@@ -14,7 +14,7 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
-*/
+ */
 #ifndef KDEVPLATFORM_CODECOMPLETIONHELPER_H
 #define KDEVPLATFORM_CODECOMPLETIONHELPER_H
 
@@ -23,14 +23,15 @@
 #include "../duchain/declaration.h"
 
 namespace KTextEditor {
-  class Document;
-  class Range;
-  class View;
+class Document;
+class Range;
+class View;
 }
 namespace KDevelop {
-  class Declaration;
-
-  void KDEVPLATFORMLANGUAGE_EXPORT insertFunctionParenText(KTextEditor::View* view, const KTextEditor::Cursor& pos, const KDevelop::DeclarationPointer& declaration, bool jumpForbidden = false);
+class Declaration;
 
+void KDEVPLATFORMLANGUAGE_EXPORT insertFunctionParenText(KTextEditor::View* view, const KTextEditor::Cursor& pos,
+                                                         const KDevelop::DeclarationPointer& declaration,
+                                                         bool jumpForbidden = false);
 }
 #endif
