@@ -15,7 +15,7 @@
     along with this library; see the file COPYING.LIB.  If not, write to
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
-*/
+ */
 
 #ifndef KDEVPLATFORM_ARCHIVETEMPLATELOADER_H
 #define KDEVPLATFORM_ARCHIVETEMPLATELOADER_H
@@ -23,12 +23,12 @@
 #include <grantlee/templateloader.h>
 
 class KArchiveDirectory;
-namespace KDevelop
-{
-
+namespace KDevelop {
 class ArchiveTemplateLocation;
+class ArchiveTemplateLoaderPrivate;
 
-class ArchiveTemplateLoader : public Grantlee::AbstractTemplateLoader
+class ArchiveTemplateLoader
+    : public Grantlee::AbstractTemplateLoader
 {
 public:
     static ArchiveTemplateLoader* self();
@@ -47,7 +47,8 @@ private:
     Q_DISABLE_COPY(ArchiveTemplateLoader)
     ArchiveTemplateLoader();
 
-    const QScopedPointer<class ArchiveTemplateLoaderPrivate> d;
+    const QScopedPointer<class ArchiveTemplateLoaderPrivate> d_ptr;
+    Q_DECLARE_PRIVATE(ArchiveTemplateLoader)
 };
 
 /**
@@ -66,9 +67,10 @@ public:
     QString templateContents(const QString& name) const;
 
 private:
+    Q_DISABLE_COPY(ArchiveTemplateLocation)
+
     const KArchiveDirectory* m_directory;
 };
-
 }
 
 #endif // KDEVPLATFORM_ARCHIVETEMPLATELOADER_H
