@@ -17,7 +17,7 @@
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
-*/
+ */
 
 #ifndef KDEVPLATFORM_ENUMERATIONTYPE_H
 #define KDEVPLATFORM_ENUMERATIONTYPE_H
@@ -26,52 +26,53 @@
 #include "identifiedtype.h"
 #include "typesystemdata.h" // for IntegralTypeData (used in EnumerationTypeBase)
 
-namespace KDevelop
-{
+namespace KDevelop {
+using EnumerationTypeBase = KDevelop::MergeIdentifiedType<IntegralType>;
 
-typedef KDevelop::MergeIdentifiedType<IntegralType> EnumerationTypeBase;
+using EnumerationTypeData = EnumerationTypeBase::Data;
 
-typedef EnumerationTypeBase::Data EnumerationTypeData;
-
-class KDEVPLATFORMLANGUAGE_EXPORT EnumerationType : public EnumerationTypeBase
+class KDEVPLATFORMLANGUAGE_EXPORT EnumerationType
+    : public EnumerationTypeBase
 {
 public:
-  EnumerationType();
+    EnumerationType();
 
-  EnumerationType(const EnumerationType& rhs);
+    EnumerationType(const EnumerationType& rhs);
 
-  explicit EnumerationType(EnumerationTypeData& data);
-  typedef TypePtr<EnumerationType> Ptr;
+    explicit EnumerationType(EnumerationTypeData& data);
 
-  uint hash() const override;
+    EnumerationType& operator=(const EnumerationType& rhs) = delete;
 
-  KDevelop::AbstractType* clone() const override;
+    using Ptr = TypePtr<EnumerationType>;
 
-  bool equals(const KDevelop::AbstractType* rhs) const override;
+    uint hash() const override;
 
-  QString toString() const override;
+    KDevelop::AbstractType* clone() const override;
 
-  WhichType whichType() const override;
+    bool equals(const KDevelop::AbstractType* rhs) const override;
 
-  enum {
-    Identity = 21
-  };
+    QString toString() const override;
 
-  typedef EnumerationTypeData Data;
+    WhichType whichType() const override;
+
+    enum {
+        Identity = 21
+    };
+
+    using Data = EnumerationTypeData;
 
 protected:
-  TYPE_DECLARE_DATA(EnumerationType);
+    TYPE_DECLARE_DATA(EnumerationType);
 };
 
-template<>
-inline EnumerationType* fastCast<EnumerationType*>(AbstractType* from) {
-  if(!from || from->whichType() != KDevelop::AbstractType::TypeEnumeration)
-    return nullptr;
-  else
-    return static_cast<EnumerationType*>(from);
+template <>
+inline EnumerationType* fastCast<EnumerationType*>(AbstractType* from)
+{
+    if (!from || from->whichType() != KDevelop::AbstractType::TypeEnumeration)
+        return nullptr;
+    else
+        return static_cast<EnumerationType*>(from);
 }
-
 }
 
-
 #endif // KDEVPLATFORM_ENUMERATIONTYPE_H
