@@ -339,7 +339,7 @@ void AbstractFileManagerPluginPrivate::deleted(const QString& path_)
                                i18n("The base folder of project <b>%1</b>"
                                     " got deleted or moved outside of KDevelop.\n"
                                     "The project has to be closed.", p->name()),
-                               i18n("Project Folder Deleted") );
+                               i18nc("@title:window", "Project Folder Deleted") );
             ICore::self()->projectController()->closeProject(p);
             continue;
         }
