@@ -123,7 +123,7 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
         const auto pluginInfos = pluginController->allPluginInfos();
         if (pluginInfos.isEmpty()) {
             QMessageBox::critical(nullptr,
-                                  i18n("Could not find any plugins"),
+                                  i18nc("@title:window", "No Plugins Found"),
                                   i18n("<p>Could not find any plugins during startup.<br/>"
                                   "Please make sure QT_PLUGIN_PATH is set correctly.</p>"
                                   "Refer to <a href=\"https://community.kde.org/Guidelines_and_HOWTOs/Build_from_source#Set_up_the_runtime_environment\">this article</a> for more information."),
@@ -238,6 +238,11 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
     qCDebug(SHELL) << "Initializing plugin controller (loading session plugins)";
     pluginController->initialize();
 
+    /* To make breakpoints show up in the UI, we need to make sure
+       DebugController is initialized and has loaded BreakpointModel
+       before UI is made visible. */
+    debugController->initialize();
+
     qCDebug(SHELL) << "Initializing working set controller";
     if(!(mode & Core::NoUi))
     {
@@ -256,7 +261,6 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
     if (documentationController) {
         documentationController->initialize();
     }
-    debugController->initialize();
     testController->initialize();
     runtimeController->initialize();
 
