@@ -23,8 +23,6 @@
 
 #include <core.h>
 
-#include <KAboutData>
-
 #include <QPointer>
 
 namespace KDevelop
@@ -69,7 +67,6 @@ public:
     QPointer<TestController> testController;
     QPointer<RuntimeController> runtimeController;
 
-    const KAboutData m_aboutData;
     Core* const m_core;
     bool m_cleanedUp;
     bool m_shuttingDown;
