@@ -12,7 +12,6 @@
 
 #include <QVBoxLayout>
 
-#include <kio_version.h>
 #include <KDirOperator>
 #include <KFileItem>
 #include <KFileWidget>
@@ -78,11 +77,7 @@ void OpenProjectPage::dirChanged(const QUrl& /*url*/)
         const KFileItemList items = fileWidget->dirOperator()->dirLister()->items();
         for (const KFileItem& item : items) {
             if(item.url().path().endsWith(ShellExtension::getInstance()->projectFileExtension()) && item.isFile()) {
-#if KIO_VERSION >= QT_VERSION_CHECK(5,33,0)
                 fileWidget->setSelectedUrl(item.url());
-#else
-                fileWidget->setSelection(item.url().url());
-#endif
             }
         }
     }
