@@ -108,7 +108,7 @@ public:
     bool m_foundProjectFile; //Temporary flag used while searching the hierarchy for a project file
     bool m_cleaningUp; //Temporary flag enabled while destroying the project-controller
     ProjectChangesModel* m_changesModel = nullptr;
-    QHash< IProject*, QPointer<KJob> > m_parseJobs; // parse jobs that add files from the project to the background parser.
+    QHash<IProject*, KJob*> m_parseJobs; // parse jobs that add files from the project to the background parser.
 
     ProjectControllerPrivate(Core* core, ProjectController* p)
         : m_core(core)
@@ -1067,6 +1067,9 @@ void ProjectController::takeProject(IProject* proj)
     // loading might have failed
     d->m_currentlyOpening.removeAll(proj->projectFile().toUrl());
     d->m_projects.removeAll(proj);
+    if (auto* job = d->m_parseJobs.value(proj)) {
+        job->kill(); // Removes job from m_parseJobs.
+    }
     emit projectClosing(proj);
     //Core::self()->saveSettings();     // The project file is being closed.
                                         // Now we can save settings for all of the Core
@@ -1369,16 +1372,23 @@ QString ProjectController::mapSourceBuild( const QString& path_, bool reverse, b
     return QString();
 }
 
-    void KDevelop::ProjectController::reparseProject(IProject *project, bool forceUpdate, bool forceAll)
-    {
+void ProjectController::reparseProject(IProject* project, bool forceUpdate, bool forceAll)
+{
     Q_D(ProjectController);
 
-    if (auto job = d->m_parseJobs.value(project)) {
-        job->kill();
+    if (auto* oldJob = d->m_parseJobs.value(project)) {
+        oldJob->kill(); // Removes oldJob from m_parseJobs.
     }
 
-    d->m_parseJobs[project] = new KDevelop::ParseProjectJob(project, forceUpdate, forceAll);
-    ICore::self()->runController()->registerJob(d->m_parseJobs[project]);
+    auto& job = d->m_parseJobs[project];
+    job = new ParseProjectJob(project, forceUpdate, forceAll || parseAllProjectSources());
+    connect(job, &KJob::finished, this, [d, project](KJob* job) {
+        const auto it = d->m_parseJobs.constFind(project);
+        if (it != d->m_parseJobs.cend() && *it == job) {
+            d->m_parseJobs.erase(it);
+        }
+    });
+    ICore::self()->runController()->registerJob(job);
 }
 
 }
