@@ -106,7 +106,7 @@ void TestProblemModel::testNoGrouping()
 
     // Check if adding the problems works
     int c = 0;
-    foreach (const IProblem::Ptr &p, m_problems) {
+    for (const IProblem::Ptr& p : qAsConst(m_problems)) {
         m_model->addProblem(p);
         c++;
 
@@ -202,7 +202,7 @@ void TestProblemModel::testPathGrouping()
 
     // Check if add problems works
     int c = 0;
-    foreach (const IProblem::Ptr &p, m_problems) {
+    for (const IProblem::Ptr& p : qAsConst(m_problems)) {
         m_model->addProblem(p);
         c++;
 
@@ -301,7 +301,7 @@ void TestProblemModel::testSeverityGrouping()
 
     // Check if adding problems works
     int c = 0;
-    foreach (const IProblem::Ptr &p, m_problems) {
+    for (const IProblem::Ptr& p : qAsConst(m_problems)) {
         m_model->addProblem(p);
         QVERIFY(checkSeverityGroup(c, m_problems[c]));
         c++;
