@@ -50,7 +50,7 @@ public:
 
 AggregateModel::AggregateModel(QObject *parent)
     :QAbstractItemModel(parent)
-    ,d(new AggregateModelPrivate())
+    ,d_ptr(new AggregateModelPrivate())
 {
 }
 
@@ -58,6 +58,8 @@ AggregateModel::~AggregateModel() = default;
 
 void AggregateModel::addModel(const QString &name, QStandardItemModel *model)
 {
+    Q_D(AggregateModel);
+
     beginResetModel();
     d->modelList << model;
     d->modelNames[model] = name;
@@ -66,6 +68,8 @@ void AggregateModel::addModel(const QString &name, QStandardItemModel *model)
 
 void AggregateModel::removeModel(QStandardItemModel *model)
 {
+    Q_D(AggregateModel);
+
     beginResetModel();
     d->modelList.removeAll(model);
     d->modelNames.remove(model);
@@ -102,6 +106,8 @@ int AggregateModel::columnCount(const QModelIndex &parent) const
 
 int AggregateModel::rowCount(const QModelIndex &parent) const
 {
+    Q_D(const AggregateModel);
+
     if (!parent.isValid())
     {
         //toplevel items represent aggregated models
@@ -122,7 +128,7 @@ int AggregateModel::rowCount(const QModelIndex &parent) const
         else
         {
             //we have a standard item in the source model - just map it into our model
-            QStandardItem *item = static_cast<QStandardItem*>(parent.internalPointer());
+            auto *item = static_cast<QStandardItem*>(parent.internalPointer());
             return item->rowCount();
         }
     }
@@ -130,6 +136,8 @@ int AggregateModel::rowCount(const QModelIndex &parent) const
 
 QVariant AggregateModel::data(const QModelIndex &index, int role) const
 {
+    Q_D(const AggregateModel);
+
     if (!index.isValid() || (role != Qt::DisplayRole))
         return QVariant();
 
@@ -141,13 +149,15 @@ QVariant AggregateModel::data(const QModelIndex &index, int role) const
     else
     {
         //we have a standard item in the source model - just map it into our model
-        QStandardItem *item = static_cast<QStandardItem*>(index.internalPointer());
+        auto *item = static_cast<QStandardItem*>(index.internalPointer());
         return item->data(role);
     }
 }
 
 QModelIndex AggregateModel::parent(const QModelIndex &index) const
 {
+    Q_D(const AggregateModel);
+
     if (!index.isValid())
         return QModelIndex();
 
@@ -158,7 +168,7 @@ QModelIndex AggregateModel::parent(const QModelIndex &index) const
     }
 
     //this is just an item from the model
-    QStandardItem *item = static_cast<QStandardItem*>(index.internalPointer());
+    auto *item = static_cast<QStandardItem*>(index.internalPointer());
     QModelIndex parent;
     if (!item->parent())
     {
@@ -179,6 +189,8 @@ QModelIndex AggregateModel::parent(const QModelIndex &index) const
 
 QModelIndex AggregateModel::index(int row, int column, const QModelIndex &parent) const
 {
+    Q_D(const AggregateModel);
+
     if (row < 0 || column < 0)
         return QModelIndex();
 
@@ -204,7 +216,7 @@ QModelIndex AggregateModel::index(int row, int column, const QModelIndex &parent
     else
     {
         //we have a standard item in the source model - just map it into our model
-        QStandardItem *parentItem = static_cast<QStandardItem*>(parent.internalPointer());
+        auto *parentItem = static_cast<QStandardItem*>(parent.internalPointer());
         return createIndex(row, column, parentItem->child(row, column));
     }
 }
