@@ -24,20 +24,23 @@
 #include "language/duchain/ducontext.h"
 
 namespace KDevelop {
+class DeclarationValidatorPrivate;
 
-class KDEVPLATFORMTESTS_EXPORT DeclarationValidator : public DUChainVisitor
+class KDEVPLATFORMTESTS_EXPORT DeclarationValidator
+    : public DUChainVisitor
 {
 public:
-  DeclarationValidator();
-  virtual ~DeclarationValidator();
+    DeclarationValidator();
+    ~DeclarationValidator() override;
+
+    virtual bool testsPassed() const;
+    void visit(DUContext*) override;
+    void visit(Declaration* declaration) override;
 
-  virtual bool testsPassed();
-  void visit(DUContext*) override;
-  void visit(Declaration *declaration) override;
 private:
-  Q_DISABLE_COPY(DeclarationValidator)
-  const QScopedPointer<class DeclarationValidatorPrivate> d;
+    Q_DISABLE_COPY(DeclarationValidator)
+    const QScopedPointer<class DeclarationValidatorPrivate> d_ptr;
+    Q_DECLARE_PRIVATE(DeclarationValidator)
 };
-
 }
-#endif //KDEVPLATFORM_DECLARATIONVALIDATOR_H
\ No newline at end of file
+#endif //KDEVPLATFORM_DECLARATIONVALIDATOR_H
