@@ -96,7 +96,11 @@ Path::List readPathListFile(const QString& filepath)
     }
 
     const QString text = QString::fromLocal8Bit(f.readAll());
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    const QStringList lines = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
+#else
     const QStringList lines = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
+#endif
     Path::List paths;
     paths.reserve(lines.length());
     for (const auto& line : lines) {
@@ -164,6 +168,7 @@ DocumentChangeTracker* trackerForUrl(const IndexedString& url)
 
 ClangParseJob::ClangParseJob(const IndexedString& url, ILanguageSupport* languageSupport)
     : ParseJob(url, languageSupport)
+    , m_options(ParseSessionData::NoOption)
 {
     const auto tuUrl = clang()->index()->translationUnitForUrl(url);
     bool hasBuildSystemInfo;
@@ -214,6 +219,9 @@ ClangParseJob::ClangParseJob(const IndexedString& url, ILanguageSupport* languag
 
     if (auto tracker = trackerForUrl(url)) {
         tracker->reset();
+        m_options |= ParseSessionData::OpenedInEditor;
+    } else if (tuUrl != url && trackerForUrl(tuUrl)) {
+        m_options |= ParseSessionData::OpenedInEditor;
     }
 }
 
@@ -383,7 +391,7 @@ void ClangParseJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread*
 
 ParseSessionData::Ptr ClangParseJob::createSessionData() const
 {
-    return ParseSessionData::Ptr(new ParseSessionData(m_unsavedFiles, clang()->index(), m_environment, ParseSessionData::NoOption));
+    return ParseSessionData::Ptr(new ParseSessionData(m_unsavedFiles, clang()->index(), m_environment, m_options));
 }
 
 const ParsingEnvironment* ClangParseJob::environment() const
