@@ -822,6 +822,7 @@ public:
         DotToArrow,
         ArrowToDot
     };
+    Q_ENUM(Type)
 
 public Q_SLOTS:
     void replaceCurrentAccess(MemberAccessReplacer::Type type)
@@ -864,8 +865,6 @@ static MemberAccessReplacer s_memberAccessReplacer;
 
 }
 
-Q_DECLARE_METATYPE(MemberAccessReplacer::Type)
-
 ClangCodeCompletionContext::ClangCodeCompletionContext(const DUContextPointer& context,
                                                        const ParseSessionData::Ptr& sessionData,
                                                        const QUrl& url,
