@@ -232,7 +232,7 @@ AbstractType::Ptr stripType(const AbstractType::Ptr& type, DUContext* ctx)
 
             AbstractType::Ptr newType(type->clone());
 
-            if (const IdentifiedType * idType = dynamic_cast<const IdentifiedType*>(type.data())) {
+            if (const auto * idType = dynamic_cast<const IdentifiedType*>(type.data())) {
                 Declaration* decl = idType->declaration(ctx->topContext());
                 if (!decl) {
                     return type;
@@ -427,8 +427,7 @@ QString makeSignatureString(const KDevelop::Declaration* functionDecl, const Sig
 
     QStringList parameters;
     parameters.reserve(signature.parameters.size());
-    foreach(const ParameterItem &item, signature.parameters)
-    {
+    for (const ParameterItem& item : signature.parameters) {
         QString parameter;
         AbstractType::Ptr type = item.first.abstractType();
 
