@@ -44,6 +44,10 @@
 
 #include <algorithm>
 
+#if HAVE_DLFCN
+#include <dlfcn.h>
+#endif
+
 using namespace KDevelop;
 
 namespace {
@@ -65,7 +69,8 @@ CXChildVisitResult visitCursor(CXCursor cursor, CXCursor, CXClientData data)
     uint line, column;
     clang_getFileLocation(location, &parentFile, &line, &column, nullptr);
 
-    foreach (const auto& import, imports->values(parentFile)) {
+    const auto parentFileImports = imports->values(parentFile);
+    for (const auto& import : parentFileImports) {
         // clang_getInclusions doesn't include the same import twice, so we shouldn't do it too.
         if (import.file == file) {
             return CXChildVisit_Continue;
@@ -79,7 +84,7 @@ CXChildVisitResult visitCursor(CXCursor cursor, CXCursor, CXClientData data)
 
 ReferencedTopDUContext createTopContext(const IndexedString& path, const ClangParsingEnvironment& environment)
 {
-    ClangParsingEnvironmentFile* file = new ClangParsingEnvironmentFile(path, environment);
+    auto* file = new ClangParsingEnvironmentFile(path, environment);
     ReferencedTopDUContext context = new ClangTopDUContext(path, RangeInRevision(0, 0, INT_MAX, INT_MAX), file);
     DUChain::self()->addDocumentChain(context);
     context->updateImportsCache();
@@ -124,7 +129,7 @@ ReferencedTopDUContext ClangHelpers::buildDUChain(CXFile file, const Imports& im
     QList<Import> sortedImports = imports.values(file);
     std::sort(sortedImports.begin(), sortedImports.end(), importLocationLessThan);
 
-    foreach(const auto& import, sortedImports) {
+    for (const auto& import : qAsConst(sortedImports)) {
         buildDUChain(import.file, imports, session, features, includedFiles, index, abortFunction);
     }
 
@@ -176,7 +181,7 @@ ReferencedTopDUContext ClangHelpers::buildDUChain(CXFile file, const Imports& im
         }
         context->setFeatures(features);
 
-        foreach(const auto& import, sortedImports) {
+        for (const auto& import : qAsConst(sortedImports)) {
             auto ctx = includedFiles.value(import.file);
             if (!ctx) {
                 // happens for cyclic imports
@@ -408,6 +413,20 @@ QString ClangHelpers::clangBuiltinIncludePath()
         }
 #endif
 
+#if HAVE_DLFCN
+        // maybe the location of clang changed, try to use the library path instead
+        // we find it by pass any symbol in libclang to dladdr
+        Dl_info info;
+        if (dladdr(reinterpret_cast<void*>(&clang_getClangVersion), &info)) {
+            dir = QDir::cleanPath(QStringLiteral("%1/../clang/%2/include")
+                .arg(QString::fromUtf8(info.dli_fname), clangVersion()));
+            if (isValidClangBuiltingIncludePath(dir)) {
+                clangDebug() << "Using builtin dir:" << dir;
+                return dir;
+            }
+        }
+#endif
+
         clangDebug() << "Using builtin dir:" << KDEV_CLANG_BUILTIN_DIR;
         return QString::fromUtf8(KDEV_CLANG_BUILTIN_DIR);
     }();
