@@ -218,15 +218,15 @@ ParseSessionData::ParseSessionData(const QVector<UnsavedFile>& unsavedFiles, Cla
     }
     if (options.testFlag(PrecompiledHeader)) {
         flags |= CXTranslationUnit_ForSerialization;
-    } else {
+    } else if (environment.quality() == ClangParsingEnvironment::Unknown) {
+        flags |= CXTranslationUnit_Incomplete;
+    }
+    if (options.testFlag(OpenedInEditor)) {
         flags |= CXTranslationUnit_CacheCompletionResults
 #if CINDEX_VERSION_MINOR >= 32
               |  CXTranslationUnit_CreatePreambleOnFirstParse
 #endif
               |  CXTranslationUnit_PrecompiledPreamble;
-        if (environment.quality() == ClangParsingEnvironment::Unknown) {
-            flags |= CXTranslationUnit_Incomplete;
-        }
     }
 
     const auto tuUrl = environment.translationUnitUrl();
@@ -442,6 +442,10 @@ IndexedString ParseSession::languageString()
 
 ClangProblem::Ptr ParseSession::getOrCreateProblem(int indexInTU, CXDiagnostic diagnostic) const
 {
+    if (!d) {
+        return {};
+    }
+
     auto& problem = d->m_diagnosticsCache[indexInTU];
     if (!problem) {
         problem = ClangDiagnosticEvaluator::createProblem(diagnostic, d->m_unit);
@@ -621,5 +625,8 @@ bool ParseSession::reparse(const QVector<UnsavedFile>& unsavedFiles, const Clang
 
 ClangParsingEnvironment ParseSession::environment() const
 {
+    if (!d) {
+        return {};
+    }
     return d->m_environment;
 }
