@@ -25,6 +25,7 @@
 #include "icmakedocumentation.h"
 #include "cmakedocumentation.h"
 #include "cmakecommandscontents.h"
+#include <QEvent>
 #include <QHeaderView>
 #include <interfaces/icore.h>
 #include <interfaces/idocumentationcontroller.h>
@@ -42,9 +43,17 @@ KDevelop::IDocumentationProvider* CMakeHomeDocumentation::provider() const
 QWidget* CMakeHomeDocumentation::documentationWidget(KDevelop::DocumentationFindWidget*, QWidget* parent)
 {
     auto* contents=new QTreeView(parent);
+    contents->viewport()->installEventFilter(this);
     contents->header()->setVisible(false);
 
     contents->setModel(CMakeDoc::s_provider->model());
     QObject::connect(contents, &QTreeView::clicked, CMakeDoc::s_provider->model(), &CMakeCommandsContents::showItemAt);
     return contents;
 }
+
+bool CMakeHomeDocumentation::eventFilter(QObject* watched, QEvent* event)
+{
+    if (event->type() == QEvent::MouseButtonPress)
+        event->ignore(); // Propagate to DocumentationView
+    return QObject::eventFilter(watched, event);
+}
