@@ -27,6 +27,7 @@
 #include <language/duchain/duchain.h>
 #include <language/backgroundparser/backgroundparser.h>
 
+#include <kcoreaddons_version.h>
 #include <KLocalizedString>
 
 CTestFindJob::CTestFindJob(CTestSuite* suite, QObject* parent)
@@ -78,6 +79,22 @@ void CTestFindJob::findTestCases()
 
 void CTestFindJob::updateReady(const KDevelop::IndexedString& document, const KDevelop::ReferencedTopDUContext& context)
 {
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 75, 0)
+    if (Q_UNLIKELY(isFinished())) {
+#else
+    if (Q_UNLIKELY(error() == KilledJobError)) {
+#endif
+        qCDebug(CMAKE) << "Cannot add test suite" << m_suite->name() << ": this job has been killed.";
+        return;
+    }
+
+    if (Q_UNLIKELY(!m_suite->project())) {
+        qCDebug(CMAKE) << "Cannot add test suite" << m_suite->name()
+                       << "because its project is already destroyed (probably closed by the user).";
+        kill();
+        return;
+    }
+
     qCDebug(CMAKE) << "context update ready" << m_pendingFiles << document.str();
     m_suite->loadDeclarations(document, context);
     m_pendingFiles.removeAll(KDevelop::Path(document.toUrl()));
