@@ -24,6 +24,7 @@
 #include <language/duchain/indexeddeclaration.h>
 #include <util/path.h>
 #include <QHash>
+#include <QPointer>
 
 namespace KDevelop {
 class ReferencedTopDUContext;
@@ -60,7 +61,7 @@ private:
     QStringList m_cases;
     QStringList m_args;
     QList<KDevelop::Path> m_files;
-    KDevelop::IProject* m_project;
+    QPointer<KDevelop::IProject> m_project;
 
     QHash<QString, KDevelop::IndexedDeclaration> m_declarations;
     QHash<QString, QString> m_properties;
