@@ -41,9 +41,9 @@ class MIVariable : public KDevelop::Variable
 
 public:
     MIVariable(MIDebugSession *session, KDevelop::TreeModel* model, KDevelop::TreeItem* parent,
-               const QString& expression, const QString& display = QLatin1String(""));
+               const QString& expression, const QString& display = QString());
 
-    ~MIVariable();
+    ~MIVariable() override;
 
     /* FIXME: should eventually remove, so that existence of
         varobjs is fully encapsulalated inside GdbVariable.  */
