@@ -55,12 +55,12 @@ FileManager::FileManager(KDevFileManagerPlugin *plugin, QWidget* parent)
 {
     setObjectName(QStringLiteral("FileManager"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("folder-sync"), windowIcon()));
-    setWindowTitle(i18n("File System"));
+    setWindowTitle(i18nc("@title:window", "File System"));
 
     KConfigGroup cg = KDevelop::ICore::self()->activeSession()->config()->group( "Filesystem" );
 
     auto *l = new QVBoxLayout(this);
-    l->setMargin(0);
+    l->setContentsMargins(0, 0, 0, 0);
     l->setSpacing(0);
     auto* model = new KFilePlacesModel( this );
     urlnav = new KUrlNavigator(model, QUrl(cg.readEntry( "LastLocation", QUrl::fromLocalFile( QDir::homePath() ) )), this );
@@ -135,14 +135,14 @@ void FileManager::updateNav( const QUrl& url )
 
 void FileManager::setupActions()
 {
-    auto* acmBookmarks = new KActionMenu(QIcon::fromTheme(QStringLiteral("bookmarks")), i18n("Bookmarks"), this);
+    auto* acmBookmarks = new KActionMenu(QIcon::fromTheme(QStringLiteral("bookmarks")), i18nc("@title:menu", "Bookmarks"), this);
     acmBookmarks->setDelayed(false);
     m_bookmarkHandler = new BookmarkHandler(this, acmBookmarks->menu());
     acmBookmarks->setShortcutContext(Qt::WidgetWithChildrenShortcut);
 
     auto* action = new QAction(this);
     action->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-    action->setText(i18n("Current Document Directory"));
+    action->setText(i18nc("@action switch to directory of current document", "Current Document Directory"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("dirsync")));
     connect(action, &QAction::triggered, this, &FileManager::syncCurrentDocumentDirectory);
     auto* diropActionCollection = dirop->actionCollection();
@@ -159,14 +159,14 @@ void FileManager::setupActions()
     };
 
     newFileAction = new QAction(this);
-    newFileAction->setText(i18n("New File..."));
+    newFileAction->setText(i18nc("@action", "New File..."));
     newFileAction->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
     connect(newFileAction, &QAction::triggered, this, &FileManager::createNewFile);
 }
 
 void FileManager::createNewFile()
 {
-    QUrl destUrl = QFileDialog::getSaveFileUrl(KDevelop::ICore::self()->uiController()->activeMainWindow(), i18n("Create New File"));
+    QUrl destUrl = QFileDialog::getSaveFileUrl(KDevelop::ICore::self()->uiController()->activeMainWindow(), i18nc("@title:window", "Create New File"));
     if (destUrl.isEmpty()) {
         return;
     }
