@@ -21,7 +21,6 @@
 
 #include "templateclassassistant.h"
 #include "debug.h"
-#include "qtcompat_p.h"
 
 #include <language/codegen/sourcefiletemplate.h>
 
@@ -135,7 +134,7 @@ void TemplateOptionsPage::load(const SourceFileTemplate& fileTemplate, TemplateR
             }
             if (control)
             {
-                const QString entryLabelText = i18n("%1:", entry.label);
+                const QString entryLabelText = i18nc("@label", "%1:", entry.label);
                 auto* label = new QLabel(entryLabelText, box);
                 if (!entry.context.isEmpty()) {
                     label->setToolTip(entry.context);
