@@ -23,7 +23,6 @@
 #include "ui_testcases.h"
 
 #include <KEditListWidget>
-#include <kwidgetsaddons_version.h>
 
 using namespace KDevelop;
 
@@ -42,15 +41,6 @@ TestCasesPage::TestCasesPage(QWidget* parent)
 
     d->ui->testCasesLabel->setBuddy(d->ui->keditlistwidget->lineEdit());
 
-#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5,32,0)
-    // workaround for KEditListWidget bug:
-    // ensure keyboard focus is returned to edit line
-    connect(d->ui->keditlistwidget, &KEditListWidget::added,
-            d->ui->keditlistwidget->lineEdit(), QOverload<>::of(&QWidget::setFocus));
-    connect(d->ui->keditlistwidget, &KEditListWidget::removed,
-            d->ui->keditlistwidget->lineEdit(), QOverload<>::of(&QWidget::setFocus));
-#endif
-
     connect(d->ui->identifierLineEdit, &QLineEdit::textChanged, this, &TestCasesPage::identifierChanged);
 }
 
