@@ -26,9 +26,12 @@
 #include "dbgglobal.h"
 #include "debuglog.h"
 
+#include <interfaces/icore.h>
+#include <interfaces/iuicontroller.h>
+#include <sublime/message.h>
+
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KMessageBox>
 #include <KShell>
 
 #include <QApplication>
@@ -75,10 +78,9 @@ bool GdbDebugger::start(KConfigGroup& config, const QStringList& extraArguments)
             info.setFile( shell_without_args );
         }*/
         if(!info.exists()) {
-            KMessageBox::information(
-                qApp->activeWindow(),
-                i18n("Could not locate the debugging shell '%1'.", shell_without_args ),
-                i18n("Debugging Shell Not Found") );
+            const QString messageText = i18n("Could not locate the debugging shell '%1'.", shell_without_args);
+            auto* message = new Sublime::Message(messageText, Sublime::Message::Error);
+            KDevelop::ICore::self()->uiController()->postMessage(message);
             return false;
         }
 
