@@ -35,7 +35,7 @@ class GrepOutputViewFactory: public KDevelop::IToolViewFactory
 public:
     explicit GrepOutputViewFactory(GrepViewPlugin* plugin);
     QWidget* create(QWidget* parent = nullptr) override;
-    Qt::DockWidgetArea defaultPosition() override;
+    Qt::DockWidgetArea defaultPosition() const override;
     QString id() const override;
 private:
     GrepViewPlugin* m_plugin;
