@@ -26,7 +26,7 @@
 #include "visualizer.h"
 
 #include <config-kdevelop.h>
-#if KF5SysGuard_FOUND
+#if HAVE_KSYSGUARD
 #include "dialogs/processselection.h"
 #include <QPointer>
 #endif
@@ -60,16 +60,16 @@ Plugin::Plugin(QObject* parent, const QVariantList&)
 
     m_launchAction = new QAction(
         QIcon::fromTheme(QStringLiteral("office-chart-area")),
-        i18n("Run Heaptrack Analysis"),
+        i18nc("@action", "Run Heaptrack Analysis"),
         this);
 
     connect(m_launchAction, &QAction::triggered, this, &Plugin::launchHeaptrack);
     actionCollection()->addAction(QStringLiteral("heaptrack_launch"), m_launchAction);
 
-#if KF5SysGuard_FOUND
+#if HAVE_KSYSGUARD
     m_attachAction = new QAction(
         QIcon::fromTheme(QStringLiteral("office-chart-area")),
-        i18n("Attach to Process with Heaptrack"),
+        i18nc("@action", "Attach to Process with Heaptrack"),
         this);
 
     connect(m_attachAction, &QAction::triggered, this, &Plugin::attachHeaptrack);
@@ -134,7 +134,7 @@ void Plugin::launchHeaptrack()
 
 void Plugin::attachHeaptrack()
 {
-#if KF5SysGuard_FOUND
+#if HAVE_KSYSGUARD
     QPointer<KDevMI::ProcessSelectionDialog> dlg = new KDevMI::ProcessSelectionDialog(activeMainWindow());
     if (!dlg->exec() || !dlg->pidSelected()) {
         delete dlg;
