@@ -63,7 +63,7 @@ KJob* MakeBuilder::install(KDevelop::ProjectBaseItem *dom, const QUrl &installPa
         args << QLatin1String("DESTDIR=") + installPath.toLocalFile();
 
     if(installAsRoot) {
-        KDevelop::BuilderJob* job = new KDevelop::BuilderJob;
+        auto* job = new KDevelop::BuilderJob;
         job->addCustomJob( KDevelop::BuilderJob::Build, build(dom), dom );
         job->addCustomJob( KDevelop::BuilderJob::Install, runMake( dom, MakeJob::InstallCommand, args ), dom );
         job->updateJobName();
@@ -74,7 +74,7 @@ KJob* MakeBuilder::install(KDevelop::ProjectBaseItem *dom, const QUrl &installPa
 
 void MakeBuilder::jobFinished(KJob* job)
 {
-    MakeJob* mj = dynamic_cast<MakeJob*>(job);
+    auto* mj = qobject_cast<MakeJob*>(job);
 
     if( !mj )
         return;
@@ -96,11 +96,13 @@ void MakeBuilder::jobFinished(KJob* job)
             case MakeJob::CleanCommand:
                 emit cleaned( mj->item() );
                 break;
-            case MakeJob::CustomTargetCommand:
-                foreach( const QString& target, mj->customTargets() ) {
+            case MakeJob::CustomTargetCommand: {
+                const auto targets = mj->customTargets();
+                for (const QString& target : targets) {
                     emit makeTargetBuilt( mj->item(), target );
                 }
                 break;
+            }
         }
     }
 }
@@ -124,15 +126,15 @@ KJob* MakeBuilder::runMake( KDevelop::ProjectBaseItem* item, MakeJob::CommandTyp
 {
     ///Running the same builder twice may result in serious problems,
     ///so kill jobs already running on the same project
-    foreach (MakeJob* makeJob, m_activeMakeJobs.data())
-    {
+    const auto makeJobs = m_activeMakeJobs.data();
+    for (MakeJob* makeJob : makeJobs) {
         if(item && makeJob->item() && makeJob->item()->project() == item->project() && makeJob->commandType() == c) {
             qCDebug(KDEV_MAKEBUILDER) << "killing running make job, due to new started build on same project:" << makeJob;
             makeJob->kill(KJob::EmitResult);
         }
     }
 
-    MakeJob* job = new MakeJob(this, item, c, overrideTargets, variables);
+    auto* job = new MakeJob(this, item, c, overrideTargets, variables);
     m_activeMakeJobs.append(job);
 
     connect(job, &MakeJob::finished, this, &MakeBuilder::jobFinished);
