@@ -270,9 +270,8 @@ QStringList MakeJob::commandLine() const
         }
     }
 
-    for (MakeVariables::const_iterator it = m_variables.constBegin(); it != m_variables.constEnd(); ++it)
-    {
-        cmdline += QStringLiteral("%1=%2").arg(it->first, it->second);
+    for (auto& variable : m_variables) {
+        cmdline += variable.first + QLatin1Char('=') + variable.second;
     }
 
     if( m_overrideTargets.isEmpty() )
@@ -312,5 +311,5 @@ QString MakeJob::environmentProfile() const
 
 bool MakeJob::isNMake(const QString& makeBin)
 {
-    return !QFileInfo(makeBin).baseName().compare(QStringLiteral("nmake"), Qt::CaseInsensitive);
+    return !QFileInfo(makeBin).baseName().compare(QLatin1String("nmake"), Qt::CaseInsensitive);
 }
