@@ -27,16 +27,26 @@
 #include <QMimeType>
 #include <QVariantList>
 
+#include <kio_version.h>
+#include <kservice_version.h>
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
+#if KSERVICE_VERSION >= QT_VERSION_CHECK(5, 68, 0)
+#include <KApplicationTrader>
+#endif
 #include <KMimeTypeTrader>
 #include <KParts/MainWindow>
 #include <KPluginFactory>
-#include <KRun>
 #include <KService>
 #include <KOpenWithDialog>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 71, 0)
+#include <KIO/ApplicationLauncherJob>
+#include <KIO/JobUiDelegate>
+#else
+#include <KRun>
+#endif
 
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/context.h>
@@ -79,7 +89,11 @@ bool canOpenDefault(const QString& mimeType)
 {
     if (defaultForMimeType(mimeType).isEmpty() && mimeType == QLatin1String("inode/directory")) {
         // potentially happens in non-kde environments apparently, see https://git.reviewboard.kde.org/r/122373
+#if KSERVICE_VERSION >= QT_VERSION_CHECK(5, 68, 0)
+        return KApplicationTrader::preferredService(mimeType);
+#else
         return KMimeTypeTrader::self()->preferredService(mimeType);
+#endif
     } else {
         return true;
     }
@@ -142,7 +156,7 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension(KDevelop::Co
     }
 
     {
-        auto other = new QAction(i18n("Other..."), parent);
+        auto other = new QAction(i18nc("@item:menu", "Other..."), parent);
         connect(other, &QAction::triggered, this, [this] {
             auto dialog = new KOpenWithDialog(m_urls, ICore::self()->uiController()->activeMainWindow());
             if (dialog->exec() == QDialog::Accepted && dialog->service()) {
@@ -153,23 +167,23 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension(KDevelop::Co
     }
 
     // Now setup a menu with actions for each part and app
-    auto* menu = new QMenu(i18n("Open With"), parent);
+    auto* menu = new QMenu(i18nc("@title:menu", "Open With"), parent);
     auto documentOpenIcon = QIcon::fromTheme( QStringLiteral("document-open") );
     menu->setIcon( documentOpenIcon );
 
     if (!partActions.isEmpty()) {
-        menu->addSection(i18n("Embedded Editors"));
+        menu->addSection(i18nc("@title:menu", "Embedded Editors"));
         menu->addActions( partActions );
     }
     if (!appActions.isEmpty()) {
-        menu->addSection(i18n("External Applications"));
+        menu->addSection(i18nc("@title:menu", "External Applications"));
         menu->addActions( appActions );
     }
 
     KDevelop::ContextMenuExtension ext;
 
     if (canOpenDefault(m_mimeType)) {
-        auto* openAction = new QAction(i18n("Open"), parent);
+        auto* openAction = new QAction(i18nc("@action:inmenu", "Open"), parent);
         openAction->setIcon( documentOpenIcon );
         connect( openAction, &QAction::triggered, this, &OpenWithPlugin::openDefault );
         ext.addAction( KDevelop::ContextMenuExtension::FileGroup, openAction );
@@ -189,7 +203,7 @@ QList<QAction*> OpenWithPlugin::actionsForServiceType(const QString& serviceType
     QAction* standardAction = nullptr;
     const QString defaultId = defaultForMimeType(m_mimeType);
     for (auto& svc : list) {
-        auto* act = new QAction(isTextEditor(svc) ? i18n("Default Editor") : svc->name(), parent);
+        auto* act = new QAction(isTextEditor(svc) ? i18nc("@item:inmenu", "Default Editor") : svc->name(), parent);
         act->setIcon( QIcon::fromTheme( svc->icon() ) );
         if (svc->storageId() == defaultId || (defaultId.isEmpty() && isTextEditor(svc))) {
             QFont font = act->font();
@@ -224,8 +238,20 @@ void OpenWithPlugin::openDefault()
 
     // default handlers
     if (m_mimeType == QLatin1String("inode/directory")) {
+#if KSERVICE_VERSION >= QT_VERSION_CHECK(5, 68, 0)
+        KService::Ptr service = KApplicationTrader::preferredService(m_mimeType);
+#else
         KService::Ptr service = KMimeTypeTrader::self()->preferredService(m_mimeType);
+#endif
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 71, 0)
+        auto* job = new KIO::ApplicationLauncherJob(service);
+        job->setUrls(m_urls);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled,
+                                                  ICore::self()->uiController()->activeMainWindow()));
+        job->start();
+#else
         KRun::runService(*service, m_urls, ICore::self()->uiController()->activeMainWindow());
+#endif
     } else {
         for (const QUrl& u : qAsConst(m_urls)) {
             ICore::self()->documentController()->openDocument( u );
@@ -241,7 +267,15 @@ void OpenWithPlugin::open( const QString& storageid )
 void OpenWithPlugin::openService(const KService::Ptr& service)
 {
     if (service->isApplication()) {
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 71, 0)
+        auto* job = new KIO::ApplicationLauncherJob(service);
+        job->setUrls(m_urls);
+        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled,
+                                                  ICore::self()->uiController()->activeMainWindow()));
+        job->start();
+#else
         KRun::runService( *service, m_urls, ICore::self()->uiController()->activeMainWindow() );
+#endif
     } else {
         QString prefName = service->desktopEntryName();
         if (isTextEditor(service)) {
@@ -261,7 +295,7 @@ void OpenWithPlugin::openService(const KService::Ptr& service)
             qApp->activeWindow(),
             i18nc("%1: mime type name, %2: app/part name", "Do you want to open all '%1' files by default with %2?",
                  m_mimeType, service->name() ),
-            i18n("Set as default?"),
+            i18nc("@title:window", "Set as Default?"),
             KStandardGuiItem::yes(), KStandardGuiItem::no(),
             QStringLiteral("OpenWith-%1").arg(m_mimeType)
         );
