@@ -37,8 +37,8 @@ namespace QmlJS
     class NodeJS;
 }
 
-typedef KDevelop::AbstractTypeBuilder<QmlJS::AST::Node, QmlJS::AST::IdentifierPropertyName, ContextBuilder> TypeBuilder;
-typedef KDevelop::AbstractDeclarationBuilder<QmlJS::AST::Node, QmlJS::AST::IdentifierPropertyName, TypeBuilder> DeclarationBuilderBase;
+using TypeBuilder = KDevelop::AbstractTypeBuilder<QmlJS::AST::Node, QmlJS::AST::IdentifierPropertyName, ContextBuilder>;
+using DeclarationBuilderBase = KDevelop::AbstractDeclarationBuilder<QmlJS::AST::Node, QmlJS::AST::IdentifierPropertyName, TypeBuilder>;
 
 class KDEVQMLJSDUCHAIN_EXPORT DeclarationBuilder : public DeclarationBuilderBase
 {
@@ -56,7 +56,7 @@ protected:
     using Visitor::visit;
     using Visitor::endVisit;
 
-    typedef QList<QPair<QmlJS::AST::StringLiteral*, QString>> ExportLiteralsAndNames;
+    using ExportLiteralsAndNames = QList<QPair<QmlJS::AST::StringLiteral*, QString>>;
 
     // Functions
     template<typename Decl>
@@ -69,7 +69,7 @@ protected:
                          QmlJS::AST::Node* body,
                          const KDevelop::RangeInRevision& bodyRange);
     template<typename Node>
-    void declareParameters(Node* node, QStringRef Node::*typeAttribute);
+    void declareParameters(Node* node, QmlJS::AST::UiQualifiedId* Node::*typeFunc);
     void endVisitFunction();    // Set the return type of the function to void if no return statement has been encountered
 
     bool visit(QmlJS::AST::FunctionDeclaration* node) override;
@@ -151,7 +151,7 @@ protected:
                                   const KDevelop::RangeInRevision& newRange,
                                   DeclarationFlags flags = NoFlags)
     {
-        DeclarationT* res = DeclarationBuilderBase::openDeclaration<DeclarationT>(id, newRange, flags);
+        auto* res = DeclarationBuilderBase::openDeclaration<DeclarationT>(id, newRange, flags);
         res->setAlwaysForceDirect(true);
         return res;
     }
