@@ -69,7 +69,7 @@ void NodeJS::createObject(const QString& name, int index, DeclarationBuilder* bu
     Identifier identifier(name);
 
     StructureType::Ptr type(new StructureType);
-    Declaration* decl = builder->openDeclaration<Declaration>(identifier, RangeInRevision());
+    auto* decl = builder->openDeclaration<Declaration>(identifier, RangeInRevision());
 
     type->setDeclaration(decl);
     decl->setAlwaysForceDirect(true);
@@ -173,13 +173,14 @@ QString NodeJS::moduleFileName(const QString& moduleName, const QString& url)
     QMutexLocker lock(&m_mutex);
     auto pair = qMakePair(moduleName, url);
 
-    if (m_cachedModuleFileNames.contains(pair)) {
-        return m_cachedModuleFileNames.value(pair);
+    const auto cachedModuleFileNameIt = m_cachedModuleFileNames.constFind(pair);
+    if (cachedModuleFileNameIt != m_cachedModuleFileNames.constEnd()) {
+        return *cachedModuleFileNameIt;
     }
 
     QString& fileName = m_cachedModuleFileNames[pair];
 
-    // Absolue and relative URLs
+    // Absolute and relative URLs
     if (moduleName.startsWith(QLatin1Char('/')) || moduleName.startsWith(QLatin1Char('.'))) {
         // NOTE: This is not portable to Windows, but the Node.js documentation
         // only talks about module names that start with /, ./ and ../ .
