@@ -40,10 +40,19 @@ HelpNetworkReply::HelpNetworkReply(const QNetworkRequest &request, const QByteAr
         QTimer::singleShot(0, this, &QNetworkReply::finished);
     }
 
-    // Fix broken CSS images (tested on Qt 5.5.1 and 5.7.0)
+#ifdef USE_QTWEBKIT
+    // Fix broken CSS images (tested on Qt 5.5.1, 5.7.0, 5.9.7 and 5.14.1)
     if (request.url().fileName() == QLatin1String("offline.css")) {
         data.replace("../images", "images");
     }
+#endif
+
+    // Fix flickering when loading, the page has the offline-simple.css stylesheet which is replaced
+    // later by offline.css  by javascript which causes flickering so we force the full stylesheet
+    // from the beginning
+    if (request.url().fileName().endsWith(QLatin1String(".html"))) {
+        data.replace("offline-simple.css", "offline.css");
+    }
 
     setHeader(QNetworkRequest::ContentTypeHeader, mimeType);
     setHeader(QNetworkRequest::ContentLengthHeader, QByteArray::number(origLen));
