@@ -62,18 +62,18 @@ void QtHelpQtDoc::registerDocumentations()
 {
     const QString qmake = qmakeCandidate();
     if (!qmake.isEmpty()) {
-        QProcess *p = new QProcess;
+        auto *p = new QProcess;
         p->setProcessChannelMode(QProcess::MergedChannels);
         p->setProgram(qmake);
         p->setArguments({QLatin1String("-query"), QLatin1String("QT_INSTALL_DOCS")});
         p->start();
-        connect(p, static_cast<void(QProcess::*)(int)>(&QProcess::finished), this, &QtHelpQtDoc::lookupDone);
+        connect(p, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &QtHelpQtDoc::lookupDone);
     }
 }
 
 void QtHelpQtDoc::lookupDone(int code)
 {
-    QProcess *p = qobject_cast<QProcess*>(sender());
+    auto *p = qobject_cast<QProcess*>(sender());
     if(code == QProcess::NormalExit) {
         m_path = QDir::fromNativeSeparators(QString::fromLatin1(p->readAllStandardOutput().trimmed()));
         qCDebug(QTHELP) << "Detected doc path:" << m_path;
@@ -109,7 +109,8 @@ void QtHelpQtDoc::loadDocumentation()
 
 void QtHelpQtDoc::unloadDocumentation()
 {
-    foreach(const QString &fileName, qchFiles()) {
+    const auto fileNames = qchFiles();
+    for (const QString& fileName : fileNames) {
         QString fileNamespace = QHelpEngineCore::namespaceName(fileName);
         if(!fileName.isEmpty() && m_engine.registeredDocumentations().contains(fileNamespace)) {
             m_engine.unregisterDocumentation(fileName);
@@ -131,7 +132,8 @@ QStringList QtHelpQtDoc::qchFiles() const
         if(path.isEmpty() || !d.exists()) {
             continue;
         }
-        foreach(const auto& file, d.entryInfoList(QDir::Files)) {
+        const auto fileInfos = d.entryInfoList(QDir::Files);
+        for (const auto& file : fileInfos) {
             files << file.absoluteFilePath();
         }
     }
