@@ -23,6 +23,9 @@
 #include "../qthelp_config_shared.h"
 
 #include <QTest>
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+#include <QHelpLink>
+#endif
 
 #include <interfaces/idocumentation.h>
 #include <language/duchain/duchainlock.h>
@@ -192,7 +195,12 @@ void TestQtHelpPlugin::testDeclarationLookup_Class()
 
     auto provider = dynamic_cast<QtHelpProviderAbstract*>(m_plugin->providers().at(0));
     QVERIFY(provider);
-    if (!provider->isValid() || provider->engine()->linksForIdentifier(QStringLiteral("QObject")).isEmpty()) {
+    if (!provider->isValid() ||
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+        provider->engine()->documentsForIdentifier(QStringLiteral("QObject")).isEmpty()) {
+#else
+        provider->engine()->linksForIdentifier(QStringLiteral("QObject")).isEmpty()) {
+#endif
         QSKIP("Qt help not available", SkipSingle);
     }
 
@@ -219,7 +227,12 @@ void TestQtHelpPlugin::testDeclarationLookup_Method()
 
     auto provider = dynamic_cast<QtHelpProviderAbstract*>(m_plugin->providers().at(0));
     QVERIFY(provider);
-    if (!provider->isValid() || provider->engine()->linksForIdentifier(QStringLiteral("QString::fromLatin1")).isEmpty()) {
+    if (!provider->isValid() ||
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+        provider->engine()->documentsForIdentifier(QStringLiteral("QString::fromLatin1")).isEmpty()) {
+#else
+        provider->engine()->linksForIdentifier(QStringLiteral("QString::fromLatin1")).isEmpty()) {
+#endif
         QSKIP("Qt help not available", SkipSingle);
     }
 
@@ -244,7 +257,12 @@ void TestQtHelpPlugin::testDeclarationLookup_OperatorFunction()
 
     auto provider = dynamic_cast<QtHelpProviderAbstract*>(m_plugin->providers().at(0));
     QVERIFY(provider);
-    if (!provider->isValid() || provider->engine()->linksForIdentifier(QStringLiteral("QObject")).isEmpty()) {
+    if (!provider->isValid() ||
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+        provider->engine()->documentsForIdentifier(QStringLiteral("QObject")).isEmpty()) {
+#else
+        provider->engine()->linksForIdentifier(QStringLiteral("QObject")).isEmpty()) {
+#endif
         QSKIP("Qt help not available", SkipSingle);
     }
 
