@@ -33,9 +33,6 @@
 #include "expandingdelegate.h"
 #include <debug.h>
 
-QIcon ExpandingWidgetModel::m_expandedIcon;
-QIcon ExpandingWidgetModel::m_collapsedIcon;
-
 using namespace KTextEditor;
 
 inline QModelIndex firstColumn(const QModelIndex& index)
@@ -386,7 +383,7 @@ void ExpandingWidgetModel::setExpanded(const QModelIndex& idx_, bool expanded)
                 m_expandingWidgets[idx] = v.value<QWidget*>();
             } else if (v.canConvert<QString>()) {
                 //Create a html widget that shows the given string
-                KTextEdit* edit = new KTextEdit(v.toString());
+                auto* edit = new KTextEdit(v.toString());
                 edit->setReadOnly(true);
                 edit->resize(200, 50); //Make the widget small so it embeds nicely.
                 m_expandingWidgets[idx] = edit;
@@ -502,17 +499,6 @@ QWidget* ExpandingWidgetModel::expandingWidget(const QModelIndex& idx_) const
     }
 }
 
-void ExpandingWidgetModel::cacheIcons() const
-{
-    if (m_expandedIcon.isNull()) {
-        m_expandedIcon = QIcon::fromTheme(QStringLiteral("arrow-down"));
-    }
-
-    if (m_collapsedIcon.isNull()) {
-        m_collapsedIcon = QIcon::fromTheme(QStringLiteral("arrow-right"));
-    }
-}
-
 QList<QVariant> mergeCustomHighlighting(int leftSize, const QList<QVariant>& left, int rightSize, const QList<QVariant>& right)
 {
     QList<QVariant> ret = left;
