@@ -63,7 +63,7 @@ void QuickOpenTestBase::cleanup()
 
 TestProject* getProjectWithFiles(int files)
 {
-    TestProject* project = new TestProject;
+    auto* project = new TestProject;
     auto* foo = createChild<ProjectFolderItem>(project->projectItem(), QStringLiteral("foo"));
     auto* bar = createChild<ProjectFolderItem>(foo, QStringLiteral("bar"));
     for (int i = 0; i < files; ++i) {
